##  Importing a Project as a New Fact Sheet
You can import an SAP Cloud ALM project to a new fact sheet either as a child fact sheet from which the synchronization setup was opened or as a new standalone fact sheet. The newly created fact sheet will inherit the name of the imported project, along with the other project data synced.
  1. In the synchronization setup overlay, select Import From SAP Cloud ALM.
  2. Select a project from the resulting drop-down list. The list shows all projects from the SAP Cloud ALM instance that you have configured.
  3. Select the check box below the drop-down list to create the new fact sheet as a child of the current fact sheet. If you unselect the check box, a new standalone fact sheet is created.
![Creating the New Fact Sheet as a Child of the Current Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275678a27a441014808ea97823f6c58d_LowRes.png)
Creating the New Fact Sheet as a Child of the Current Fact Sheet
  4. Click Create and Sync.
